@@ -606,8 +606,11 @@ class BusServer (Bus):
                 if sys.platform != 'darwin':
                     self.__logger.error('Unexpected timeout in acceptClients: "%s"', e)
             except Exception, e:
-                self.__logger.error('Exception in acceptClients: "%s"', e)
-                pass
+                if self.__active:
+                    self.__logger.error('Exception in acceptClients: "%s"', e,
+                                        exc_info=True)
+                else:
+                    self.__logger.info('Acceptor thread terminating')
 
     # Receiving notifications
 
@@ -643,6 +646,8 @@ class BusServer (Bus):
         if not self.__active:
             raise RuntimeError, 'Trying to deactivate inactive BusServer'
 
+        self.__active = False
+
         # If necessary, close the listening socket. This causes an
         # exception in the acceptor thread.
         self.__logger.info('Closing listen socket')
@@ -663,8 +668,6 @@ class BusServer (Bus):
         if not self.__acceptorThread is None:
             self.__acceptorThread.join()
 
-        self.__active = False
-
         super(BusServer, self).deactivate()
 
 def removeConnector(bus, connector):
@@ -804,8 +807,6 @@ class InPushConnector (Connector,
                                                converter  = converter)
         self.__action(event)
 
-rsb.transport.addConnector(InPushConnector)
-
 class OutConnector (Connector,
                     rsb.transport.OutConnector):
     """
@@ -830,4 +831,24 @@ class OutConnector (Connector,
                                        data       = wireData)
         self.bus.handleOutgoing(notification)
 
-rsb.transport.addConnector(OutConnector)
+class TransportFactory(rsb.transport.TransportFactory):
+    """
+    L{TransportFactory} implementation for the socket transport.
+
+    @author: jwienke
+    """
+
+    def getName(self):
+        return "socket"
+
+    def createInPushConnector(self, converters, options):
+        return InPushConnector(converters=converters, options=options)
+
+    def createOutConnector(self, converters, options):
+        return OutConnector(converters=converters, options=options)
+
+def initialize():
+    try:
+        rsb.transport.registerTransport(TransportFactory())
+    except ValueError:
+        pass
